# Project:   SPRtools


# Toolflags:
GCCOpts      = -mamu -mthrowback -mlibscl -mtune=strongarm
GCCWarn      = -Wall -Wparentheses -Wunused
CCflags      = -c $(GCCOpts) $(GCCWarn) -DRISCOS
Link         = gcc
LinkFlags    = -mlibscl -o $@
ObjAsmflags  = -depend !Depend -ThrowBack -Stamp -quit -CloseExec
CMHGflags    = -26bit -depend !Depend -throwback
LibFileflags = -c -o $@
Squeezeflags = -v $@
AAsmflags    = -depend !Depend -quit -CloseExec -To $@ -From


# Final targets:
all:    @.bin.spr_fsi     \
        @.bin.spr_diff    \
        @.bin.spr_pal     \
        @.bin.spr4spr     \
        @.bin.spr3spr     \
        @.bin.spr2xbm     \
        @.bin.spr2bmp     \
        @.bin.spr2ras     \
        @.bin.spr2sb      \
        @.bin.spr2tga     \
        @.bin.spr2xwd     \
        @.bin.spr2clr     \
        @.bin.bmp2spr     \
        @.bin.ras2spr     \
        @.bin.sb2spr      \
        @.bin.tga2spr     \
        @.bin.xwd2spr     \
        @.bin.clr2spr     \
        @.bin.bmp_info    \
        @.bin.ras_info    \
        @.bin.sb_info     \
        @.bin.tga_info    \
        @.bin.xwd_info    \
        @.bin.clr_info    \
        @.bin.spr_info    \
        @.bin.chmode

.SUFFIXES: .o .c

.c.o:;  gcc $(ccflags) $<


@.o.conv_lib: @.o.io	  \
	      @.o.sprite  \
	      @.o.colours \
	      @.o.process \
	      @.o.palette
        libfile $(LibFileflags) @.o.io	    \
                                @.o.sprite  \
                                @.o.colours \
                                @.o.process \
                                @.o.palette


@.bin.spr_fsi: @.o.spr_fsi @.o.conv_lib 
        $(Link) $(LinkFlags) @.o.spr_fsi @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr_diff: @.o.spr_diff @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr_diff @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr_pal: @.o.spr_pal @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr_pal @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr4spr: @.o.spr4spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr4spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr3spr: @.o.spr3spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr3spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2xbm: @.o.spr2xbm @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2xbm @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2bmp: @.o.spr2bmp @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2bmp @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2ras: @.o.spr2ras @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2ras @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2sb:  @.o.spr2sb @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2sb @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2tga: @.o.spr2tga @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2tga @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2xwd: @.o.spr2xwd @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2xwd @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr2clr: @.o.spr2clr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr2clr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.bmp2spr: @.o.bmp2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.bmp2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.ras2spr: @.o.ras2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.ras2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.sb2spr: @.o.sb2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.sb2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.tga2spr: @.o.tga2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.tga2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.xwd2spr: @.o.xwd2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.xwd2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.clr2spr: @.o.clr2spr @.o.conv_lib
        $(Link) $(LinkFlags) @.o.clr2spr @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.bmp_info:   @.o.bmp_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.bmp_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.ras_info:   @.o.ras_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.ras_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.sb_info:   @.o.sb_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.sb_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.tga_info:  @.o.tga_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.tga_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.xwd_info:  @.o.xwd_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.xwd_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.clr_info:  @.o.clr_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.clr_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.spr_info:  @.o.spr_info @.o.conv_lib
        $(Link) $(LinkFlags) @.o.spr_info @.o.conv_lib 
        Squeeze $(Squeezeflags)

@.bin.chmode:  @.o.chmode @.o.conv_lib
        $(Link) $(LinkFlags) @.o.chmode @.o.conv_lib 
        Squeeze $(Squeezeflags)


# Dynamic dependencies:

o.spr_diff: c.spr_diff gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string gccpkg:include.libscl.h.math h.io h.sprite

o.spr_pal: c.spr_pal gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.process h.colours h.palette

o.spr3spr: c.spr3spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite

o.spr2xbm: c.spr2xbm gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite

o.spr2bmp: c.spr2bmp gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.bmp h.sprite

o.spr2ras: c.spr2ras gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.ras

o.spr2sb: c.spr2sb gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.sb

o.spr2tga: c.spr2tga gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.tga

o.spr2xwd: c.spr2xwd gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.xwd

o.spr2clr: c.spr2clr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.clear

o.bmp2spr: c.bmp2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.bmp h.sprite

o.ras2spr: c.ras2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.ras

o.sb2spr: c.sb2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.sb

o.tga2spr: c.tga2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.tga

o.xwd2spr: c.xwd2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.xwd


o.bmp_info: c.bmp_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.bmp

o.ras_info: c.ras_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.ras

o.sb_info: c.sb_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sb

o.tga_info: c.tga_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.tga

o.xwd_info: c.xwd_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.xwd

o.clr_info: c.clr_info gccpkg:include.libscl.h.stdio gccpkg:include.libscl.h.stddef gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.clear

o.spr_info: c.spr_info gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.palette

o.chmode: c.chmode gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite



o.colours: c.colours gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.sprite h.io h.colours

o.process: c.process gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string gccpkg:include.libscl.h.math h.sprite h.io h.colours h.palette h.process

o.palette: c.palette gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.process h.colours h.palette

o.clr2spr: c.clr2spr gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.clear

o.io: c.io gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io

o.sprite: c.sprite gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite

o.spr_fsi: c.spr_fsi gccpkg:include.libscl.h.stdlib gccpkg:include.libscl.h.stddef gccpkg:include.libscl.h.errno gccpkg:include.libscl.h.stdio gccpkg:lib.gcc-lib.arm-riscos-aof.2_95_4.include.h.stdarg gccpkg:include.libscl.h.string h.io h.sprite h.process h.colours h.palette

